@@ -1,8 +1,8 @@
 # SPDX-License-Identifier: MIT
-# Copyright (c) 2021-2025 Daniel Perna, SukramJ
+# Copyright (c) 2021-2025
 #!/usr/bin/python3
 """
-Commandline tool to query HomeMatic hubs via XML-RPC.
+Commandline tool to query Homematic hubs via XML-RPC.
 
 Public API of this module is defined by __all__.
 
@@ -13,6 +13,7 @@ exposes the 'main' entrypoint for invocation. All other names are internal.
 from __future__ import annotations
 
 import argparse
+import json
 import sys
 from typing import Any
 from xmlrpc.client import ServerProxy
@@ -28,7 +29,7 @@ __all__ = ["main"]
 def main() -> None:
     """Start the cli."""
     parser = argparse.ArgumentParser(
-        description="Commandline tool to query HomeMatic hubs via XML-RPC",
+        description="Commandline tool to query Homematic hubs via XML-RPC",
     )
     parser.add_argument("--version", action="version", version=__version__)
     parser.add_argument(
@@ -85,18 +86,18 @@ def main() -> None:
         "-a",
         required=True,
         type=str,
-        help="Address of HomeMatic device, including channel",
+        help="Address of Homematic device, including channel",
     )
     parser.add_argument(
         "--paramset_key",
         default=ParamsetKey.VALUES,
         choices=[ParamsetKey.VALUES, ParamsetKey.MASTER],
-        help="Paramset of HomeMatic device. Default: VALUES",
+        help="Paramset of Homematic device. Default: VALUES",
     )
     parser.add_argument(
         "--parameter",
         required=True,
-        help="Parameter of HomeMatic device",
+        help="Parameter of Homematic device",
     )
     parser.add_argument(
         "--value",
@@ -124,11 +125,15 @@ def main() -> None:
 
     try:
         if args.paramset_key == ParamsetKey.VALUES and args.value is None:
-            proxy.getValue(args.address, args.parameter)
+            result = proxy.getValue(args.address, args.parameter)
             if args.json:
-                pass
+                print(
+                    json.dumps(
+                        {"address": args.address, "parameter": args.parameter, "value": result}, ensure_ascii=False
+                    )
+                )
             else:
-                pass
+                print(result)
             sys.exit(0)
         elif args.paramset_key == ParamsetKey.VALUES and args.value:
             value: Any
@@ -144,13 +149,22 @@ def main() -> None:
             sys.exit(0)
         elif args.paramset_key == ParamsetKey.MASTER and args.value is None:
             paramset: dict[str, Any] | None
-            if (paramset := proxy.getParamset(args.address, args.paramset_key)) and paramset.get(  # type: ignore[assignment]
-                args.parameter
-            ):
+            if (paramset := proxy.getParamset(args.address, args.paramset_key)) and (args.parameter in paramset):  # type: ignore[assignment]
+                result = paramset[args.parameter]
                 if args.json:
-                    pass
+                    print(
+                        json.dumps(
+                            {
+                                "address": args.address,
+                                "paramset_key": args.paramset_key,
+                                "parameter": args.parameter,
+                                "value": result,
+                            },
+                            ensure_ascii=False,
+                        )
+                    )
                 else:
-                    pass
+                    print(result)
             sys.exit(0)
         elif args.paramset_key == ParamsetKey.MASTER and args.value:
             if args.type == "int":
@@ -163,7 +177,8 @@ def main() -> None:
                 value = args.value
             proxy.putParamset(args.address, args.paramset_key, {args.parameter: value})
             sys.exit(0)
-    except Exception:
+    except Exception as ex:
+        print(str(ex), file=sys.stderr)
         sys.exit(1)
 
 
