@@ -1,3 +1,5 @@
+# SPDX-License-Identifier: MIT
+# Copyright (c) 2021-2025
 """Module for data points implemented using the light category."""
 
 from __future__ import annotations
@@ -14,8 +16,8 @@ from aiohomematic.model.custom.const import DeviceProfile, Field
 from aiohomematic.model.custom.data_point import CustomDataPoint
 from aiohomematic.model.custom.support import CustomConfig, ExtendedConfig
 from aiohomematic.model.data_point import CallParameterCollector, bind_collector
-from aiohomematic.model.decorators import state_property
 from aiohomematic.model.generic import DpAction, DpFloat, DpInteger, DpSelect, DpSensor, GenericDataPoint
+from aiohomematic.property_decorators import state_property
 
 _DIMMER_OFF: Final = 0.0
 _EFFECT_OFF: Final = "Off"
@@ -135,7 +137,7 @@ class LightOffArgs(TypedDict, total=False):
 
 
 class CustomDpDimmer(CustomDataPoint):
-    """Base class for HomeMatic light data point."""
+    """Base class for Homematic light data point."""
 
     __slots__ = (
         "_dp_group_level",
@@ -230,7 +232,7 @@ class CustomDpDimmer(CustomDataPoint):
         return None
 
     @bind_collector()
-    async def turn_on(self, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
+    async def turn_on(self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
         """Turn the light on."""
         if (on_time := kwargs.get("on_time")) is not None:
             self.set_timer_on_time(on_time=on_time)
@@ -247,7 +249,9 @@ class CustomDpDimmer(CustomDataPoint):
         await self._dp_level.send_value(value=level, collector=collector)
 
     @bind_collector()
-    async def turn_off(self, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOffArgs]) -> None:
+    async def turn_off(
+        self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOffArgs]
+    ) -> None:
         """Turn the light off."""
         self.reset_timer_on_time()
         if not self.is_state_change(off=True, **kwargs):
@@ -257,15 +261,19 @@ class CustomDpDimmer(CustomDataPoint):
         await self._dp_level.send_value(value=_DIMMER_OFF, collector=collector)
 
     @bind_collector()
-    async def _set_on_time_value(self, on_time: float, collector: CallParameterCollector | None = None) -> None:
+    async def _set_on_time_value(self, *, on_time: float, collector: CallParameterCollector | None = None) -> None:
         """Set the on time value in seconds."""
         await self._dp_on_time_value.send_value(value=on_time, collector=collector, do_validate=False)
 
-    async def _set_ramp_time_on_value(self, ramp_time: float, collector: CallParameterCollector | None = None) -> None:
+    async def _set_ramp_time_on_value(
+        self, *, ramp_time: float, collector: CallParameterCollector | None = None
+    ) -> None:
         """Set the ramp time value in seconds."""
         await self._dp_ramp_time_value.send_value(value=ramp_time, collector=collector)
 
-    async def _set_ramp_time_off_value(self, ramp_time: float, collector: CallParameterCollector | None = None) -> None:
+    async def _set_ramp_time_off_value(
+        self, *, ramp_time: float, collector: CallParameterCollector | None = None
+    ) -> None:
         """Set the ramp time value in seconds."""
         await self._set_ramp_time_on_value(ramp_time=ramp_time, collector=collector)
 
@@ -297,7 +305,7 @@ class CustomDpDimmer(CustomDataPoint):
 
 
 class CustomDpColorDimmer(CustomDpDimmer):
-    """Class for HomeMatic dimmer with color data point."""
+    """Class for Homematic dimmer with color data point."""
 
     __slots__ = ("_dp_color",)
 
@@ -321,7 +329,7 @@ class CustomDpColorDimmer(CustomDpDimmer):
         return _MIN_HUE, _MIN_SATURATION
 
     @bind_collector()
-    async def turn_on(self, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
+    async def turn_on(self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
         """Turn the light on."""
         if not self.is_state_change(on=True, **kwargs):
             return
@@ -335,7 +343,7 @@ class CustomDpColorDimmer(CustomDpDimmer):
 
 
 class CustomDpColorDimmerEffect(CustomDpColorDimmer):
-    """Class for HomeMatic dimmer with color data point."""
+    """Class for Homematic dimmer with color data point."""
 
     __slots__ = ("_dp_effect",)
 
@@ -344,7 +352,7 @@ class CustomDpColorDimmerEffect(CustomDpColorDimmer):
         "Slow color change",
         "Medium color change",
         "Fast color change",
-        "Campfire",
+        "Campemit",
         "Waterfall",
         "TV simulation",
     )
@@ -367,7 +375,7 @@ class CustomDpColorDimmerEffect(CustomDpColorDimmer):
         return self._effects
 
     @bind_collector()
-    async def turn_on(self, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
+    async def turn_on(self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
         """Turn the light on."""
         if not self.is_state_change(on=True, **kwargs):
             return
@@ -386,7 +394,7 @@ class CustomDpColorDimmerEffect(CustomDpColorDimmer):
 
 
 class CustomDpColorTempDimmer(CustomDpDimmer):
-    """Class for HomeMatic dimmer with color temperature."""
+    """Class for Homematic dimmer with color temperature."""
 
     __slots__ = ("_dp_color_level",)
 
@@ -403,7 +411,7 @@ class CustomDpColorTempDimmer(CustomDpDimmer):
         )
 
     @bind_collector()
-    async def turn_on(self, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
+    async def turn_on(self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
         """Turn the light on."""
         if not self.is_state_change(on=True, **kwargs):
             return
@@ -471,29 +479,29 @@ class CustomDpIpRGBWLight(CustomDpDimmer):
     @property
     def _relevant_data_points(self) -> tuple[GenericDataPoint, ...]:
         """Returns the list of relevant data points. To be overridden by subclasses."""
-        if self._dp_device_operation_mode.value == _DeviceOperationMode.RGBW:
+        if self._device_operation_mode == _DeviceOperationMode.RGBW:
             return (
                 self._dp_hue,
                 self._dp_level,
                 self._dp_saturation,
                 self._dp_color_temperature_kelvin,
             )
-        if self._dp_device_operation_mode.value == _DeviceOperationMode.RGB:
+        if self._device_operation_mode == _DeviceOperationMode.RGB:
             return self._dp_hue, self._dp_level, self._dp_saturation
-        if self._dp_device_operation_mode.value == _DeviceOperationMode.TUNABLE_WHITE:
+        if self._device_operation_mode == _DeviceOperationMode.TUNABLE_WHITE:
             return self._dp_level, self._dp_color_temperature_kelvin
         return (self._dp_level,)
 
     @property
     def supports_color_temperature(self) -> bool:
         """Flag if light supports color temperature."""
-        return self._dp_device_operation_mode.value == _DeviceOperationMode.TUNABLE_WHITE
+        return self._device_operation_mode == _DeviceOperationMode.TUNABLE_WHITE
 
     @property
     def supports_effects(self) -> bool:
         """Flag if light supports effects."""
         return (
-            self._dp_device_operation_mode.value != _DeviceOperationMode.PWM
+            self._device_operation_mode != _DeviceOperationMode.PWM
             and self.effects is not None
             and len(self.effects) > 0
         )
@@ -501,7 +509,7 @@ class CustomDpIpRGBWLight(CustomDpDimmer):
     @property
     def supports_hs_color(self) -> bool:
         """Flag if light supports color."""
-        return self._dp_device_operation_mode.value in (
+        return self._device_operation_mode in (
             _DeviceOperationMode.RGBW,
             _DeviceOperationMode.RGB,
         )
@@ -514,11 +522,9 @@ class CustomDpIpRGBWLight(CustomDpDimmer):
         Avoid creating data points that are not usable in selected device operation mode.
         """
         if (
-            self._dp_device_operation_mode.value in (_DeviceOperationMode.RGB, _DeviceOperationMode.RGBW)
+            self._device_operation_mode in (_DeviceOperationMode.RGB, _DeviceOperationMode.RGBW)
             and self._channel.no in (2, 3, 4)
-        ) or (
-            self._dp_device_operation_mode.value == _DeviceOperationMode.TUNABLE_WHITE and self._channel.no in (3, 4)
-        ):
+        ) or (self._device_operation_mode == _DeviceOperationMode.TUNABLE_WHITE and self._channel.no in (3, 4)):
             return DataPointUsage.NO_CREATE
         return self._get_data_point_usage()
 
@@ -528,7 +534,7 @@ class CustomDpIpRGBWLight(CustomDpDimmer):
         return self._dp_effect.values or ()
 
     @bind_collector()
-    async def turn_on(self, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
+    async def turn_on(self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
         """Turn the light on."""
         if on_time := (kwargs.get("on_time") or self.get_and_start_timer()):
             kwargs["on_time"] = on_time
@@ -549,28 +555,41 @@ class CustomDpIpRGBWLight(CustomDpDimmer):
         await super().turn_on(collector=collector, **kwargs)
 
     @bind_collector()
-    async def turn_off(self, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOffArgs]) -> None:
+    async def turn_off(
+        self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOffArgs]
+    ) -> None:
         """Turn the light off."""
         if kwargs.get("on_time") is None and kwargs.get("ramp_time"):
             await self._set_on_time_value(on_time=_NOT_USED, collector=collector)
         await super().turn_off(collector=collector, **kwargs)
 
+    @property
+    def _device_operation_mode(self) -> _DeviceOperationMode:
+        """Return the device operation mode."""
+        if (mode := self._dp_device_operation_mode.value) is None:
+            return _DeviceOperationMode.RGBW
+        return _DeviceOperationMode(mode)
+
     @bind_collector()
-    async def _set_on_time_value(self, on_time: float, collector: CallParameterCollector | None = None) -> None:
+    async def _set_on_time_value(self, *, on_time: float, collector: CallParameterCollector | None = None) -> None:
         """Set the on time value in seconds."""
         on_time, on_time_unit = _recalc_unit_timer(time=on_time)
         if on_time_unit is not None:
             await self._dp_on_time_unit.send_value(value=on_time_unit, collector=collector)
         await self._dp_on_time_value.send_value(value=float(on_time), collector=collector)
 
-    async def _set_ramp_time_on_value(self, ramp_time: float, collector: CallParameterCollector | None = None) -> None:
+    async def _set_ramp_time_on_value(
+        self, *, ramp_time: float, collector: CallParameterCollector | None = None
+    ) -> None:
         """Set the ramp time value in seconds."""
         ramp_time, ramp_time_unit = _recalc_unit_timer(time=ramp_time)
         if ramp_time_unit is not None:
             await self._dp_ramp_time_unit.send_value(value=ramp_time_unit, collector=collector)
         await self._dp_ramp_time_value.send_value(value=float(ramp_time), collector=collector)
 
-    async def _set_ramp_time_off_value(self, ramp_time: float, collector: CallParameterCollector | None = None) -> None:
+    async def _set_ramp_time_off_value(
+        self, *, ramp_time: float, collector: CallParameterCollector | None = None
+    ) -> None:
         """Set the ramp time value in seconds."""
         ramp_time, ramp_time_unit = _recalc_unit_timer(time=ramp_time)
         if ramp_time_unit is not None:
@@ -635,7 +654,7 @@ class CustomDpIpDrgDaliLight(CustomDpDimmer):
         return self._dp_effect.values or ()
 
     @bind_collector()
-    async def turn_on(self, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
+    async def turn_on(self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
         """Turn the light on."""
         if not self.is_state_change(on=True, **kwargs):
             return
@@ -654,21 +673,25 @@ class CustomDpIpDrgDaliLight(CustomDpDimmer):
         await super().turn_on(collector=collector, **kwargs)
 
     @bind_collector()
-    async def _set_on_time_value(self, on_time: float, collector: CallParameterCollector | None = None) -> None:
+    async def _set_on_time_value(self, *, on_time: float, collector: CallParameterCollector | None = None) -> None:
         """Set the on time value in seconds."""
         on_time, on_time_unit = _recalc_unit_timer(time=on_time)
         if on_time_unit:
             await self._dp_on_time_unit.send_value(value=on_time_unit, collector=collector)
         await self._dp_on_time_value.send_value(value=float(on_time), collector=collector)
 
-    async def _set_ramp_time_on_value(self, ramp_time: float, collector: CallParameterCollector | None = None) -> None:
+    async def _set_ramp_time_on_value(
+        self, *, ramp_time: float, collector: CallParameterCollector | None = None
+    ) -> None:
         """Set the ramp time value in seconds."""
         ramp_time, ramp_time_unit = _recalc_unit_timer(time=ramp_time)
         if ramp_time_unit:
             await self._dp_ramp_time_unit.send_value(value=ramp_time_unit, collector=collector)
         await self._dp_ramp_time_value.send_value(value=float(ramp_time), collector=collector)
 
-    async def _set_ramp_time_off_value(self, ramp_time: float, collector: CallParameterCollector | None = None) -> None:
+    async def _set_ramp_time_off_value(
+        self, *, ramp_time: float, collector: CallParameterCollector | None = None
+    ) -> None:
         """Set the ramp time value in seconds."""
         ramp_time, ramp_time_unit = _recalc_unit_timer(time=ramp_time)
         if ramp_time_unit:
@@ -744,12 +767,12 @@ class CustomDpIpFixedColorLight(CustomDpDimmer):
         return None
 
     @bind_collector()
-    async def turn_on(self, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
+    async def turn_on(self, *, collector: CallParameterCollector | None = None, **kwargs: Unpack[LightOnArgs]) -> None:
         """Turn the light on."""
         if not self.is_state_change(on=True, **kwargs):
             return
         if (hs_color := kwargs.get("hs_color")) is not None:
-            simple_rgb_color = _convert_color(hs_color)
+            simple_rgb_color = _convert_color(color=hs_color)
             await self._dp_color.send_value(value=simple_rgb_color, collector=collector)
         elif self.color_name in _NO_COLOR:
             await self._dp_color.send_value(value=_FixedColor.WHITE, collector=collector)
@@ -763,14 +786,16 @@ class CustomDpIpFixedColorLight(CustomDpDimmer):
         await super().turn_on(collector=collector, **kwargs)
 
     @bind_collector()
-    async def _set_on_time_value(self, on_time: float, collector: CallParameterCollector | None = None) -> None:
+    async def _set_on_time_value(self, *, on_time: float, collector: CallParameterCollector | None = None) -> None:
         """Set the on time value in seconds."""
         on_time, on_time_unit = _recalc_unit_timer(time=on_time)
         if on_time_unit:
             await self._dp_on_time_unit.send_value(value=on_time_unit, collector=collector)
         await self._dp_on_time_value.send_value(value=float(on_time), collector=collector)
 
-    async def _set_ramp_time_on_value(self, ramp_time: float, collector: CallParameterCollector | None = None) -> None:
+    async def _set_ramp_time_on_value(
+        self, *, ramp_time: float, collector: CallParameterCollector | None = None
+    ) -> None:
         """Set the ramp time value in seconds."""
         ramp_time, ramp_time_unit = _recalc_unit_timer(time=ramp_time)
         if ramp_time_unit:
@@ -778,7 +803,7 @@ class CustomDpIpFixedColorLight(CustomDpDimmer):
         await self._dp_ramp_time_value.send_value(value=float(ramp_time), collector=collector)
 
 
-def _recalc_unit_timer(time: float) -> tuple[float, int | None]:
+def _recalc_unit_timer(*, time: float) -> tuple[float, int | None]:
     """Recalculate unit and value of timer."""
     ramp_time_unit = _TimeUnit.SECONDS
     if time == _NOT_USED:
@@ -792,7 +817,7 @@ def _recalc_unit_timer(time: float) -> tuple[float, int | None]:
     return time, ramp_time_unit
 
 
-def _convert_color(color: tuple[float, float]) -> str:
+def _convert_color(*, color: tuple[float, float]) -> str:
     """
     Convert the given color to the reduced color of the device.
 
@@ -816,6 +841,7 @@ def _convert_color(color: tuple[float, float]) -> str:
 
 
 def make_ip_dimmer(
+    *,
     channel: hmd.Channel,
     custom_config: CustomConfig,
 ) -> None:
@@ -829,10 +855,11 @@ def make_ip_dimmer(
 
 
 def make_rf_dimmer(
+    *,
     channel: hmd.Channel,
     custom_config: CustomConfig,
 ) -> None:
-    """Create HomeMatic classic dimmer data point."""
+    """Create Homematic classic dimmer data point."""
     hmed.make_custom_data_point(
         channel=channel,
         data_point_class=CustomDpDimmer,
@@ -842,10 +869,11 @@ def make_rf_dimmer(
 
 
 def make_rf_dimmer_color(
+    *,
     channel: hmd.Channel,
     custom_config: CustomConfig,
 ) -> None:
-    """Create HomeMatic classic dimmer with color data point."""
+    """Create Homematic classic dimmer with color data point."""
     hmed.make_custom_data_point(
         channel=channel,
         data_point_class=CustomDpColorDimmer,
@@ -855,10 +883,11 @@ def make_rf_dimmer_color(
 
 
 def make_rf_dimmer_color_fixed(
+    *,
     channel: hmd.Channel,
     custom_config: CustomConfig,
 ) -> None:
-    """Create HomeMatic classic dimmer with fixed color data point."""
+    """Create Homematic classic dimmer with fixed color data point."""
     hmed.make_custom_data_point(
         channel=channel,
         data_point_class=CustomDpColorDimmer,
@@ -868,10 +897,11 @@ def make_rf_dimmer_color_fixed(
 
 
 def make_rf_dimmer_color_effect(
+    *,
     channel: hmd.Channel,
     custom_config: CustomConfig,
 ) -> None:
-    """Create HomeMatic classic dimmer and effect with color data point."""
+    """Create Homematic classic dimmer and effect with color data point."""
     hmed.make_custom_data_point(
         channel=channel,
         data_point_class=CustomDpColorDimmerEffect,
@@ -881,10 +911,11 @@ def make_rf_dimmer_color_effect(
 
 
 def make_rf_dimmer_color_temp(
+    *,
     channel: hmd.Channel,
     custom_config: CustomConfig,
 ) -> None:
-    """Create HomeMatic classic dimmer with color temperature data point."""
+    """Create Homematic classic dimmer with color temperature data point."""
     hmed.make_custom_data_point(
         channel=channel,
         data_point_class=CustomDpColorTempDimmer,
@@ -894,10 +925,11 @@ def make_rf_dimmer_color_temp(
 
 
 def make_rf_dimmer_with_virt_channel(
+    *,
     channel: hmd.Channel,
     custom_config: CustomConfig,
 ) -> None:
-    """Create HomeMatic classic dimmer data point."""
+    """Create Homematic classic dimmer data point."""
     hmed.make_custom_data_point(
         channel=channel,
         data_point_class=CustomDpDimmer,
@@ -907,6 +939,7 @@ def make_rf_dimmer_with_virt_channel(
 
 
 def make_ip_fixed_color_light(
+    *,
     channel: hmd.Channel,
     custom_config: CustomConfig,
 ) -> None:
@@ -920,6 +953,7 @@ def make_ip_fixed_color_light(
 
 
 def make_ip_simple_fixed_color_light_wired(
+    *,
     channel: hmd.Channel,
     custom_config: CustomConfig,
 ) -> None:
@@ -933,6 +967,7 @@ def make_ip_simple_fixed_color_light_wired(
 
 
 def make_ip_rgbw_light(
+    *,
     channel: hmd.Channel,
     custom_config: CustomConfig,
 ) -> None:
@@ -946,6 +981,7 @@ def make_ip_rgbw_light(
 
 
 def make_ip_drg_dali_light(
+    *,
     channel: hmd.Channel,
     custom_config: CustomConfig,
 ) -> None:
@@ -1068,6 +1104,7 @@ DEVICES: Mapping[str, CustomConfig | tuple[CustomConfig, ...]] = {
     "HmIP-FDT": CustomConfig(make_ce_func=make_ip_dimmer, channels=(2,)),
     "HmIP-PDT": CustomConfig(make_ce_func=make_ip_dimmer, channels=(3,)),
     "HmIP-RGBW": CustomConfig(make_ce_func=make_ip_rgbw_light),
+    "HmIP-LSC": CustomConfig(make_ce_func=make_ip_rgbw_light),
     "HmIP-SCTH230": CustomConfig(
         make_ce_func=make_ip_dimmer,
         channels=(12,),
