@@ -1,7 +1,9 @@
+# SPDX-License-Identifier: MIT
+# Copyright (c) 2021-2025
 """
 Device and channel model for AioHomematic.
 
-This module implements the runtime representation of a HomeMatic device and its
+This module implements the runtime representation of a Homematic device and its
 channels, including creation and lookup of data points/events, firmware and
 availability handling, link management, value caching, and exporting of device
 definitions for diagnostics.
@@ -69,19 +71,20 @@ from aiohomematic.exceptions import AioHomematicException, BaseHomematicExceptio
 from aiohomematic.model.calculated import CalculatedDataPoint
 from aiohomematic.model.custom import data_point as hmce, definition as hmed
 from aiohomematic.model.data_point import BaseParameterDataPoint, CallbackDataPoint
-from aiohomematic.model.decorators import cached_slot_property, info_property, state_property
 from aiohomematic.model.event import GenericEvent
 from aiohomematic.model.generic import GenericDataPoint
 from aiohomematic.model.support import (
     ChannelNameData,
-    PayloadMixin,
     generate_channel_unique_id,
     get_channel_name_data,
     get_device_name,
 )
 from aiohomematic.model.update import DpUpdate
+from aiohomematic.property_decorators import hm_property, info_property, state_property
 from aiohomematic.support import (
     CacheEntry,
+    LogContextMixin,
+    PayloadMixin,
     check_or_create_directory,
     extract_exc_args,
     get_channel_address,
@@ -94,20 +97,21 @@ __all__ = ["Channel", "Device"]
 _LOGGER: Final = logging.getLogger(__name__)
 
 
-class Device(PayloadMixin):
+class Device(LogContextMixin, PayloadMixin):
     """Object to hold information about a device and associated data points."""
 
     __slots__ = (
         "_address",
         "_cached_relevant_for_central_link_management",
         "_central",
-        "_channel_groups",
+        "_channel_group",
         "_channels",
         "_client",
         "_description",
         "_device_updated_callbacks",
         "_firmware_update_callbacks",
         "_forced_availability",
+        "_group_channels",
         "_has_custom_data_point_definition",
         "_id",
         "_ignore_for_custom_data_point",
@@ -127,13 +131,14 @@ class Device(PayloadMixin):
         "_value_cache",
     )
 
-    def __init__(self, central: hmcu.CentralUnit, interface_id: str, device_address: str) -> None:
+    def __init__(self, *, central: hmcu.CentralUnit, interface_id: str, device_address: str) -> None:
         """Initialize the device object."""
         PayloadMixin.__init__(self)
         self._central: Final = central
         self._interface_id: Final = interface_id
         self._address: Final = device_address
-        self._channel_groups: Final[dict[int | None, int]] = {}
+        self._channel_group: Final[dict[int | None, int]] = {}
+        self._group_channels: Final[dict[int, set[int | None]]] = {}
         self._id: Final = self._central.device_details.get_address_id(address=device_address)
         self._interface: Final = central.device_details.get_interface(address=device_address)
         self._client: Final = central.get_client(interface_id=interface_id)
@@ -159,7 +164,7 @@ class Device(PayloadMixin):
             model=self._model
         )
         self._manufacturer = self._identify_manufacturer()
-        self._product_group: Final = self._client.get_product_group(self._model)
+        self._product_group: Final = self._client.get_product_group(model=self._model)
         # marker if device will be created as custom data_point
         self._has_custom_data_point_definition: Final = (
             hmed.data_point_definition_exists(model=self._model) and not self._ignore_for_custom_data_point
@@ -194,7 +199,7 @@ class Device(PayloadMixin):
             return Manufacturer.MOEHLENHOFF
         return Manufacturer.EQ3
 
-    @info_property
+    @info_property(log_context=True)
     def address(self) -> str:
         """Return the address of the device."""
         return self._address
@@ -302,7 +307,18 @@ class Device(PayloadMixin):
     @property
     def has_sub_devices(self) -> bool:
         """Return if device has multiple sub device channels."""
-        return len(set(self._channel_groups.values())) > 1
+        # If there is only one channel group, no sub devices are needed
+        if len(self._group_channels) <= 1:
+            return False
+        count = 0
+        # If there are multiple channel groups with more than one channel, there are sub devices
+        for gcs in self._group_channels.values():
+            if len(gcs) > 1:
+                count += 1
+            if count > 1:
+                return True
+
+        return False
 
     @property
     def id(self) -> str:
@@ -324,7 +340,7 @@ class Device(PayloadMixin):
         """Return the interface of the device."""
         return self._interface
 
-    @property
+    @hm_property(log_context=True)
     def interface_id(self) -> str:
         """Return the interface_id of the device."""
         return self._interface_id
@@ -351,7 +367,7 @@ class Device(PayloadMixin):
         """Return the manufacturer of the device."""
         return self._manufacturer
 
-    @info_property
+    @info_property(log_context=True)
     def model(self) -> str:
         """Return the model of the device."""
         return self._model
@@ -368,7 +384,7 @@ class Device(PayloadMixin):
 
     @info_property
     def room(self) -> str | None:
-        """Return the room of the device, if only one assigned in CCU."""
+        """Return the room of the device, if only one assigned in the backend."""
         if self._rooms and len(self._rooms) == 1:
             return list(self._rooms)[0]
         if (maintenance_channel := self.get_channel(channel_address=f"{self._address}:0")) is not None:
@@ -415,30 +431,32 @@ class Device(PayloadMixin):
         """Return th CONFIG_PENDING data_point."""
         return self.get_generic_data_point(channel_address=f"{self._address}:0", parameter=Parameter.CONFIG_PENDING)
 
-    def add_channel_to_group(self, channel_no: int | None, group_no: int) -> None:
-        """Add channel no group."""
-        if group_no not in self._channel_groups:
-            self._channel_groups[group_no] = group_no
-        if channel_no not in self._channel_groups:
-            self._channel_groups[channel_no] = group_no
-        elif self._channel_groups[channel_no] != group_no:
-            return
+    def add_channel_to_group(self, *, group_no: int, channel_no: int | None) -> None:
+        """Add channel to group."""
+        if group_no not in self._group_channels:
+            self._group_channels[group_no] = set()
+        self._group_channels[group_no].add(channel_no)
 
-    @inspector()
+        if group_no not in self._channel_group:
+            self._channel_group[group_no] = group_no
+        if channel_no not in self._channel_group:
+            self._channel_group[channel_no] = group_no
+
+    @inspector
     async def create_central_links(self) -> None:
         """Create a central links to support press events on all channels with click events."""
         if self.relevant_for_central_link_management:  # pylint: disable=using-constant-test
             for channel in self._channels.values():
                 await channel.create_central_link()
 
-    @inspector()
+    @inspector
     async def remove_central_links(self) -> None:
         """Remove central links."""
         if self.relevant_for_central_link_management:  # pylint: disable=using-constant-test
             for channel in self._channels.values():
                 await channel.remove_central_link()
 
-    @cached_slot_property
+    @hm_property(cached=True)
     def relevant_for_central_link_management(self) -> bool:
         """Return if channel is relevant for central link management."""
         return (
@@ -446,22 +464,22 @@ class Device(PayloadMixin):
             and self._model not in VIRTUAL_REMOTE_MODELS
         )
 
-    def get_channel_group_no(self, channel_no: int | None) -> int | None:
+    def get_channel_group_no(self, *, channel_no: int | None) -> int | None:
         """Return the group no of the channel."""
-        return self._channel_groups.get(channel_no)
+        return self._channel_group.get(channel_no)
 
-    def is_in_multi_channel_group(self, channel_no: int | None) -> bool:
+    def is_in_multi_channel_group(self, *, channel_no: int | None) -> bool:
         """Return if multiple channels are in the group."""
         if channel_no is None:
             return False
 
-        return len([s for s, m in self._channel_groups.items() if m == self._channel_groups.get(channel_no)]) > 1
+        return len([s for s, m in self._channel_group.items() if m == self._channel_group.get(channel_no)]) > 1
 
-    def get_channel(self, channel_address: str) -> Channel | None:
+    def get_channel(self, *, channel_address: str) -> Channel | None:
         """Get channel of device."""
         return self._channels.get(channel_address)
 
-    def identify_channel(self, text: str) -> Channel | None:
+    def identify_channel(self, *, text: str) -> Channel | None:
         """Identify channel within a text."""
         for channel_address, channel in self._channels.items():
             if text.endswith(channel_address):
@@ -478,26 +496,26 @@ class Device(PayloadMixin):
         for channel in self._channels.values():
             channel.remove()
 
-    def register_device_updated_callback(self, cb: Callable) -> CALLBACK_TYPE:
+    def register_device_updated_callback(self, *, cb: Callable) -> CALLBACK_TYPE:
         """Register update callback."""
         if callable(cb) and cb not in self._device_updated_callbacks:
             self._device_updated_callbacks.append(cb)
             return partial(self.unregister_device_updated_callback, cb=cb)
         return None
 
-    def unregister_device_updated_callback(self, cb: Callable) -> None:
+    def unregister_device_updated_callback(self, *, cb: Callable) -> None:
         """Remove update callback."""
         if cb in self._device_updated_callbacks:
             self._device_updated_callbacks.remove(cb)
 
-    def register_firmware_update_callback(self, cb: Callable) -> CALLBACK_TYPE:
+    def register_firmware_update_callback(self, *, cb: Callable) -> CALLBACK_TYPE:
         """Register firmware update callback."""
         if callable(cb) and cb not in self._firmware_update_callbacks:
             self._firmware_update_callbacks.append(cb)
             return partial(self.unregister_firmware_update_callback, cb=cb)
         return None
 
-    def unregister_firmware_update_callback(self, cb: Callable) -> None:
+    def unregister_firmware_update_callback(self, *, cb: Callable) -> None:
         """Remove firmware update callback."""
         if cb in self._firmware_update_callbacks:
             self._firmware_update_callbacks.remove(cb)
@@ -507,6 +525,7 @@ class Device(PayloadMixin):
 
     def get_data_points(
         self,
+        *,
         category: DataPointCategory | None = None,
         exclude_no_create: bool = True,
         registered: bool | None = None,
@@ -530,7 +549,7 @@ class Device(PayloadMixin):
         return tuple(all_data_points)
 
     def get_events(
-        self, event_type: EventType, registered: bool | None = None
+        self, *, event_type: EventType, registered: bool | None = None
     ) -> Mapping[int | None, tuple[GenericEvent, ...]]:
         """Return a list of specific events of a channel."""
         events: dict[int | None, tuple[GenericEvent, ...]] = {}
@@ -539,13 +558,13 @@ class Device(PayloadMixin):
                 events[channel.no] = values
         return events
 
-    def get_calculated_data_point(self, channel_address: str, parameter: str) -> CalculatedDataPoint | None:
+    def get_calculated_data_point(self, *, channel_address: str, parameter: str) -> CalculatedDataPoint | None:
         """Return a calculated data_point from device."""
         if channel := self.get_channel(channel_address=channel_address):
             return channel.get_calculated_data_point(parameter=parameter)
         return None
 
-    def get_custom_data_point(self, channel_no: int) -> hmce.CustomDataPoint | None:
+    def get_custom_data_point(self, *, channel_no: int) -> hmce.CustomDataPoint | None:
         """Return a custom data_point from device."""
         if channel := self.get_channel(
             channel_address=get_channel_address(device_address=self._address, channel_no=channel_no)
@@ -554,34 +573,34 @@ class Device(PayloadMixin):
         return None
 
     def get_generic_data_point(
-        self, channel_address: str, parameter: str, paramset_key: ParamsetKey | None = None
+        self, *, channel_address: str, parameter: str, paramset_key: ParamsetKey | None = None
     ) -> GenericDataPoint | None:
         """Return a generic data_point from device."""
         if channel := self.get_channel(channel_address=channel_address):
             return channel.get_generic_data_point(parameter=parameter, paramset_key=paramset_key)
         return None
 
-    def get_generic_event(self, channel_address: str, parameter: str) -> GenericEvent | None:
+    def get_generic_event(self, *, channel_address: str, parameter: str) -> GenericEvent | None:
         """Return a generic event from device."""
         if channel := self.get_channel(channel_address=channel_address):
             return channel.get_generic_event(parameter=parameter)
         return None
 
-    def get_readable_data_points(self, paramset_key: ParamsetKey) -> tuple[GenericDataPoint, ...]:
+    def get_readable_data_points(self, *, paramset_key: ParamsetKey) -> tuple[GenericDataPoint, ...]:
         """Return the list of readable master data points."""
         data_points: list[GenericDataPoint] = []
         for channel in self._channels.values():
             data_points.extend(channel.get_readable_data_points(paramset_key=paramset_key))
         return tuple(data_points)
 
-    def set_forced_availability(self, forced_availability: ForcedDeviceAvailability) -> None:
+    def set_forced_availability(self, *, forced_availability: ForcedDeviceAvailability) -> None:
         """Set the availability of the device."""
         if self._forced_availability != forced_availability:
             self._forced_availability = forced_availability
             for dp in self.generic_data_points:
-                dp.fire_data_point_updated_callback()
+                dp.emit_data_point_updated_event()
 
-    @inspector()
+    @inspector
     async def export_device_definition(self) -> None:
         """Export the device definition for current device."""
         try:
@@ -610,9 +629,9 @@ class Device(PayloadMixin):
             for callback_handler in self._firmware_update_callbacks:
                 callback_handler()
 
-    @inspector()
-    async def update_firmware(self, refresh_after_update_intervals: tuple[int, ...]) -> bool:
-        """Update the firmware of the homematic device."""
+    @inspector
+    async def update_firmware(self, *, refresh_after_update_intervals: tuple[int, ...]) -> bool:
+        """Update the firmware of the Homematic device."""
         update_result = await self._client.update_device_firmware(device_address=self._address)
 
         async def refresh_data() -> None:
@@ -621,11 +640,11 @@ class Device(PayloadMixin):
                 await self._central.refresh_firmware_data(device_address=self._address)
 
         if refresh_after_update_intervals:
-            self._central.looper.create_task(target=refresh_data(), name="refresh_firmware_data")
+            self._central.looper.create_task(target=refresh_data, name="refresh_firmware_data")
 
         return update_result
 
-    @inspector()
+    @inspector
     async def load_value_cache(self) -> None:
         """Init the parameter cache."""
         if len(self.generic_data_points) > 0:
@@ -637,7 +656,7 @@ class Device(PayloadMixin):
             self._address,
         )
 
-    @inspector()
+    @inspector
     async def reload_paramset_descriptions(self) -> None:
         """Reload paramset for device."""
         for (
@@ -652,20 +671,20 @@ class Device(PayloadMixin):
                     channel_address=channel_address,
                     paramset_key=paramset_key,
                 )
-        await self._central.save_caches(save_paramset_descriptions=True)
+        await self._central.save_files(save_paramset_descriptions=True)
         for dp in self.generic_data_points:
             dp.update_parameter_data()
-        self.fire_device_updated_callback()
+        self.emit_device_updated_callback()
 
     @loop_check
-    def fire_device_updated_callback(self, *args: Any) -> None:
+    def emit_device_updated_callback(self) -> None:
         """Do what is needed when the state of the device has been updated."""
         self._set_modified_at()
         for callback_handler in self._device_updated_callbacks:
             try:
-                callback_handler(*args)
+                callback_handler()
             except Exception as exc:
-                _LOGGER.warning("FIRE_DEVICE_UPDATED failed: %s", extract_exc_args(exc=exc))
+                _LOGGER.warning("EMIT_DEVICE_UPDATED failed: %s", extract_exc_args(exc=exc))
 
     def __str__(self) -> str:
         """Provide some useful information."""
@@ -680,7 +699,7 @@ class Device(PayloadMixin):
         )
 
 
-class Channel(PayloadMixin):
+class Channel(LogContextMixin, PayloadMixin):
     """Object to hold information about a channel and associated data points."""
 
     __slots__ = (
@@ -706,7 +725,7 @@ class Channel(PayloadMixin):
         "_unique_id",
     )
 
-    def __init__(self, device: Device, channel_address: str) -> None:
+    def __init__(self, *, device: Device, channel_address: str) -> None:
         """Initialize the channel object."""
         PayloadMixin.__init__(self)
 
@@ -734,7 +753,7 @@ class Channel(PayloadMixin):
         self._rooms: Final = self._central.device_details.get_channel_rooms(channel_address=channel_address)
         self._function: Final = self._central.device_details.get_function_text(address=self._address)
 
-    @property
+    @info_property
     def address(self) -> str:
         """Return the address of the channel."""
         return self._address
@@ -759,7 +778,7 @@ class Channel(PayloadMixin):
         """Return the device description for the channel."""
         return self._description
 
-    @property
+    @hm_property(log_context=True)
     def device(self) -> Device:
         """Return the device of the channel."""
         return self._device
@@ -791,7 +810,9 @@ class Channel(PayloadMixin):
             return None
         if self._group_master is None:
             self._group_master = (
-                self if self.is_group_master else self._device.get_channel(f"{self._device.address}:{self.group_no}")
+                self
+                if self.is_group_master
+                else self._device.get_channel(channel_address=f"{self._device.address}:{self.group_no}")
             )
         return self._group_master
 
@@ -829,7 +850,7 @@ class Channel(PayloadMixin):
         """Return the name data of the channel."""
         return self._name_data
 
-    @property
+    @hm_property(log_context=True)
     def no(self) -> int | None:
         """Return the channel_no of the channel."""
         return self._no
@@ -857,7 +878,7 @@ class Channel(PayloadMixin):
 
     @info_property
     def room(self) -> str | None:
-        """Return the room of the device, if only one assigned in CCU."""
+        """Return the room of the device, if only one assigned in the backend."""
         if self._rooms and len(self._rooms) == 1:
             return list(self._rooms)[0]
         if self.is_group_master:
@@ -881,7 +902,7 @@ class Channel(PayloadMixin):
         """Return the unique_id of the channel."""
         return self._unique_id
 
-    @inspector()
+    @inspector
     async def create_central_link(self) -> None:
         """Create a central link to support press events."""
         if self._has_key_press_events and not await self._has_central_link():
@@ -889,7 +910,7 @@ class Channel(PayloadMixin):
                 address=self._address, value_id=REPORT_VALUE_USAGE_VALUE_ID, ref_counter=1
             )
 
-    @inspector()
+    @inspector
     async def remove_central_link(self) -> None:
         """Remove a central link."""
         if self._has_key_press_events and await self._has_central_link() and not await self._has_program_ids():
@@ -897,7 +918,7 @@ class Channel(PayloadMixin):
                 address=self._address, value_id=REPORT_VALUE_USAGE_VALUE_ID, ref_counter=0
             )
 
-    @inspector()
+    @inspector
     async def cleanup_central_link_metadata(self) -> None:
         """Cleanup the metadata for central links."""
         if metadata := await self._device.client.get_metadata(address=self._address, data_id=REPORT_VALUE_USAGE_DATA):
@@ -934,7 +955,7 @@ class Channel(PayloadMixin):
         """Return if channel has KEYPRESS events."""
         return any(event for event in self.generic_events if event.event_type is EventType.KEYPRESS)
 
-    def add_data_point(self, data_point: CallbackDataPoint) -> None:
+    def add_data_point(self, *, data_point: CallbackDataPoint) -> None:
         """Add a data_point to a channel."""
         if isinstance(data_point, BaseParameterDataPoint):
             self._central.add_event_subscription(data_point=data_point)
@@ -942,13 +963,13 @@ class Channel(PayloadMixin):
             self._calculated_data_points[data_point.dpk] = data_point
         if isinstance(data_point, GenericDataPoint):
             self._generic_data_points[data_point.dpk] = data_point
-            self._device.register_device_updated_callback(cb=data_point.fire_data_point_updated_callback)
+            self._device.register_device_updated_callback(cb=data_point.emit_data_point_updated_event)
         if isinstance(data_point, hmce.CustomDataPoint):
             self._custom_data_point = data_point
         if isinstance(data_point, GenericEvent):
             self._generic_events[data_point.dpk] = data_point
 
-    def _remove_data_point(self, data_point: CallbackDataPoint) -> None:
+    def _remove_data_point(self, *, data_point: CallbackDataPoint) -> None:
         """Remove a data_point from a channel."""
         if isinstance(data_point, BaseParameterDataPoint):
             self._central.remove_event_subscription(data_point=data_point)
@@ -956,35 +977,36 @@ class Channel(PayloadMixin):
             del self._calculated_data_points[data_point.dpk]
         if isinstance(data_point, GenericDataPoint):
             del self._generic_data_points[data_point.dpk]
-            self._device.unregister_device_updated_callback(cb=data_point.fire_data_point_updated_callback)
+            self._device.unregister_device_updated_callback(cb=data_point.emit_data_point_updated_event)
         if isinstance(data_point, hmce.CustomDataPoint):
             self._custom_data_point = None
         if isinstance(data_point, GenericEvent):
             del self._generic_events[data_point.dpk]
-        data_point.fire_device_removed_callback()
+        data_point.emit_device_removed_event()
 
     def remove(self) -> None:
         """Remove data points from collections and central."""
         for event in self.generic_events:
-            self._remove_data_point(event)
+            self._remove_data_point(data_point=event)
         self._generic_events.clear()
 
         for ccdp in self.calculated_data_points:
-            self._remove_data_point(ccdp)
+            self._remove_data_point(data_point=ccdp)
         self._calculated_data_points.clear()
 
         for gdp in self.generic_data_points:
-            self._remove_data_point(gdp)
+            self._remove_data_point(data_point=gdp)
         self._generic_data_points.clear()
 
         if self._custom_data_point:
-            self._remove_data_point(self._custom_data_point)
+            self._remove_data_point(data_point=self._custom_data_point)
 
     def _set_modified_at(self) -> None:
         self._modified_at = datetime.now()
 
     def get_data_points(
         self,
+        *,
         category: DataPointCategory | None = None,
         exclude_no_create: bool = True,
         registered: bool | None = None,
@@ -1005,7 +1027,7 @@ class Channel(PayloadMixin):
             and (registered is None or dp.is_registered == registered)
         )
 
-    def get_events(self, event_type: EventType, registered: bool | None = None) -> tuple[GenericEvent, ...]:
+    def get_events(self, *, event_type: EventType, registered: bool | None = None) -> tuple[GenericEvent, ...]:
         """Return a list of specific events of a channel."""
         return tuple(
             event
@@ -1013,7 +1035,7 @@ class Channel(PayloadMixin):
             if (event.event_type == event_type and (registered is None or event.is_registered == registered))
         )
 
-    def get_calculated_data_point(self, parameter: str) -> CalculatedDataPoint | None:
+    def get_calculated_data_point(self, *, parameter: str) -> CalculatedDataPoint | None:
         """Return a calculated data_point from device."""
         return self._calculated_data_points.get(
             DataPointKey(
@@ -1025,7 +1047,7 @@ class Channel(PayloadMixin):
         )
 
     def get_generic_data_point(
-        self, parameter: str, paramset_key: ParamsetKey | None = None
+        self, *, parameter: str, paramset_key: ParamsetKey | None = None
     ) -> GenericDataPoint | None:
         """Return a generic data_point from device."""
         if paramset_key:
@@ -1056,7 +1078,7 @@ class Channel(PayloadMixin):
             )
         )
 
-    def get_generic_event(self, parameter: str) -> GenericEvent | None:
+    def get_generic_event(self, *, parameter: str) -> GenericEvent | None:
         """Return a generic event from device."""
         return self._generic_events.get(
             DataPointKey(
@@ -1067,7 +1089,7 @@ class Channel(PayloadMixin):
             )
         )
 
-    def get_readable_data_points(self, paramset_key: ParamsetKey) -> tuple[GenericDataPoint, ...]:
+    def get_readable_data_points(self, *, paramset_key: ParamsetKey) -> tuple[GenericDataPoint, ...]:
         """Return the list of readable master data points."""
         return tuple(
             ge for ge in self._generic_data_points.values() if ge.is_readable and ge.paramset_key == paramset_key
@@ -1096,7 +1118,7 @@ class _ValueCache:
 
     _NO_VALUE_CACHE_ENTRY: Final = "NO_VALUE_CACHE_ENTRY"
 
-    def __init__(self, device: Device) -> None:
+    def __init__(self, *, device: Device) -> None:
         """Init the value cache."""
         self._sema_get_or_load_value: Final = asyncio.Semaphore()
         self._device: Final = device
@@ -1148,6 +1170,7 @@ class _ValueCache:
 
     async def get_value(
         self,
+        *,
         dpk: DataPointKey,
         call_source: CallSource,
         direct_call: bool = False,
@@ -1186,8 +1209,8 @@ class _ValueCache:
                 else value
             )
 
-    async def _get_values_for_cache(self, dpk: DataPointKey) -> dict[str, Any]:
-        """Return a value from CCU to store in cache."""
+    async def _get_values_for_cache(self, *, dpk: DataPointKey) -> dict[str, Any]:
+        """Return a value from the backend to store in cache."""
         if not self._device.available:
             _LOGGER.debug(
                 "GET_VALUES_FOR_CACHE failed: device %s (%s) is not available", self._device.name, self._device.address
@@ -1206,17 +1229,18 @@ class _ValueCache:
             address=dpk.channel_address, paramset_key=dpk.paramset_key, call_source=CallSource.HM_INIT
         )
 
-    def _add_entry_to_device_cache(self, dpk: DataPointKey, value: Any) -> None:
+    def _add_entry_to_device_cache(self, *, dpk: DataPointKey, value: Any) -> None:
         """Add value to cache."""
         # write value to cache even if an exception has occurred
-        # to avoid repetitive calls to CCU within max_age
+        # to avoid repetitive calls to the backend within max_age
         self._device_cache[dpk] = CacheEntry(value=value, refresh_at=datetime.now())
 
     def _get_value_from_cache(
         self,
+        *,
         dpk: DataPointKey,
     ) -> Any:
-        """Load data from caches."""
+        """Load data from store."""
         # Try to get data from central cache
         if (
             dpk.paramset_key == ParamsetKey.VALUES
@@ -1245,19 +1269,19 @@ class _DefinitionExporter:
         "_device_address",
         "_interface_id",
         "_random_id",
-        "_storage_folder",
+        "_storage_directory",
     )
 
-    def __init__(self, device: Device) -> None:
+    def __init__(self, *, device: Device) -> None:
         """Init the device exporter."""
         self._client: Final = device.client
         self._central: Final = device.client.central
-        self._storage_folder: Final = self._central.config.storage_folder
+        self._storage_directory: Final = self._central.config.storage_directory
         self._interface_id: Final = device.interface_id
         self._device_address: Final = device.address
         self._random_id: Final[str] = f"VCU{int(random.randint(1000000, 9999999))}"
 
-    @inspector()
+    @inspector
     async def export_data(self) -> None:
         """Export data."""
         device_descriptions: Mapping[str, DeviceDescription] = (
@@ -1269,7 +1293,7 @@ class _DefinitionExporter:
             str, dict[ParamsetKey, dict[str, ParameterData]]
         ] = await self._client.get_all_paramset_descriptions(device_descriptions=tuple(device_descriptions.values()))
         model = device_descriptions[self._device_address]["TYPE"]
-        filename = f"{model}.json"
+        file_name = f"{model}.json"
 
         # anonymize device_descriptions
         anonymize_device_descriptions: list[DeviceDescription] = []
@@ -1280,7 +1304,7 @@ class _DefinitionExporter:
                 new_device_description["PARENT"] = new_device_description["ADDRESS"].split(ADDRESS_SEPARATOR)[0]
             elif new_device_description.get("CHILDREN"):
                 new_device_description["CHILDREN"] = [
-                    self._anonymize_address(a) for a in new_device_description["CHILDREN"]
+                    self._anonymize_address(address=a) for a in new_device_description["CHILDREN"]
                 ]
             anonymize_device_descriptions.append(new_device_description)
 
@@ -1291,33 +1315,30 @@ class _DefinitionExporter:
 
         # Save device_descriptions for device to file.
         await self._save(
-            file_dir=f"{self._storage_folder}/{DEVICE_DESCRIPTIONS_DIR}",
-            filename=filename,
+            directory=f"{self._storage_directory}/{DEVICE_DESCRIPTIONS_DIR}",
+            file_name=file_name,
             data=anonymize_device_descriptions,
         )
 
         # Save device_descriptions for device to file.
         await self._save(
-            file_dir=f"{self._storage_folder}/{PARAMSET_DESCRIPTIONS_DIR}",
-            filename=filename,
+            directory=f"{self._storage_directory}/{PARAMSET_DESCRIPTIONS_DIR}",
+            file_name=file_name,
             data=anonymize_paramset_descriptions,
         )
 
-    def _anonymize_address(self, address: str) -> str:
+    def _anonymize_address(self, *, address: str) -> str:
         address_parts = address.split(ADDRESS_SEPARATOR)
         address_parts[0] = self._random_id
         return ADDRESS_SEPARATOR.join(address_parts)
 
-    async def _save(self, file_dir: str, filename: str, data: Any) -> DataOperationResult:
+    async def _save(self, *, directory: str, file_name: str, data: Any) -> DataOperationResult:
         """Save file to disk."""
 
         def perform_save() -> DataOperationResult:
-            if not check_or_create_directory(file_dir):
+            if not check_or_create_directory(directory=directory):
                 return DataOperationResult.NO_SAVE  # pragma: no cover
-            with open(
-                file=os.path.join(file_dir, filename),
-                mode="wb",
-            ) as fptr:
+            with open(file=os.path.join(directory, file_name), mode="wb") as fptr:
                 fptr.write(orjson.dumps(data, option=orjson.OPT_INDENT_2 | orjson.OPT_NON_STR_KEYS))
             return DataOperationResult.SAVE_SUCCESS
 
