@@ -1,14 +1,14 @@
 # SPDX-License-Identifier: MIT
-# Copyright (c) 2021-2025 Daniel Perna, SukramJ
+# Copyright (c) 2021-2025
 """
 Event model for AioHomematic.
 
-This module defines the event data point hierarchy used to expose HomeMatic
+This module defines the event data point hierarchy used to expose Homematic
 button presses, device errors, and impulse notifications to applications.
 
 Included classes:
 - GenericEvent: Base event that integrates with the common data point API
-  (category, usage, names/paths, callbacks) and provides fire_event handling.
+  (category, usage, names/paths, callbacks) and provides emit_event handling.
 - ClickEvent: Represents key press events (EventType.KEYPRESS).
 - DeviceErrorEvent: Represents device error signaling with special value change
   semantics before emitting an event (EventType.DEVICE_ERROR).
@@ -73,6 +73,7 @@ class GenericEvent(BaseParameterDataPoint[Any, Any]):
 
     def __init__(
         self,
+        *,
         channel: hmd.Channel,
         parameter: str,
         parameter_data: ParameterData,
@@ -98,17 +99,17 @@ class GenericEvent(BaseParameterDataPoint[Any, Any]):
         """Return the event_type of the event."""
         return self._event_type
 
-    async def event(self, value: Any, received_at: datetime) -> None:
+    async def event(self, *, value: Any, received_at: datetime) -> None:
         """Handle event for which this handler has subscribed."""
         if self.event_type in DATA_POINT_EVENTS:
-            self.fire_data_point_updated_callback()
+            self.emit_data_point_updated_event()
         self._set_modified_at(modified_at=received_at)
-        self.fire_event(value)
+        self.emit_event(value=value)
 
     @loop_check
-    def fire_event(self, value: Any) -> None:
-        """Do what is needed to fire an event."""
-        self._central.fire_homematic_callback(event_type=self.event_type, event_data=self.get_event_data(value=value))
+    def emit_event(self, *, value: Any) -> None:
+        """Do what is needed to emit an event."""
+        self._central.emit_homematic_callback(event_type=self.event_type, event_data=self.get_event_data(value=value))
 
     def _get_data_point_name(self) -> DataPointNameData:
         """Create the name for the data_point."""
@@ -137,7 +138,7 @@ class DeviceErrorEvent(GenericEvent):
 
     _event_type = EventType.DEVICE_ERROR
 
-    async def event(self, value: Any, received_at: datetime) -> None:
+    async def event(self, *, value: Any, received_at: datetime) -> None:
         """Handle event for which this handler has subscribed."""
         old_value, new_value = self.write_value(value=value, write_at=received_at)
 
@@ -148,7 +149,7 @@ class DeviceErrorEvent(GenericEvent):
             isinstance(new_value, int)
             and ((old_value is None and new_value > 0) or (isinstance(old_value, int) and old_value != new_value))
         ):
-            self.fire_event(value=new_value)
+            self.emit_event(value=new_value)
 
 
 class ImpulseEvent(GenericEvent):
@@ -173,7 +174,7 @@ def create_event_and_append_to_channel(channel: hmd.Channel, parameter: str, par
             event_t=event_t, channel=channel, parameter=parameter, parameter_data=parameter_data
         )
     ):
-        channel.add_data_point(event)
+        channel.add_data_point(data_point=event)
 
 
 def _determine_event_type(parameter: str, parameter_data: ParameterData) -> type[GenericEvent] | None:
