@@ -1,6 +1,6 @@
 # SPDX-License-Identifier: MIT
-# Copyright (c) 2021-2025 Daniel Perna, SukramJ
-"""Generic python representation of a CCU parameter."""
+# Copyright (c) 2021-2025
+"""Generic python representation of a backend parameter."""
 
 from __future__ import annotations
 
@@ -21,7 +21,7 @@ from aiohomematic.decorators import inspector
 from aiohomematic.exceptions import ValidationException
 from aiohomematic.model import data_point as hme, device as hmd
 from aiohomematic.model.support import DataPointNameData, GenericParameterType, get_data_point_name_data
-from aiohomematic.property_decorators import cached_property
+from aiohomematic.property_decorators import hm_property
 
 _LOGGER: Final = logging.getLogger(__name__)
 
@@ -38,6 +38,7 @@ class GenericDataPoint[ParameterT: GenericParameterType, InputParameterT: Generi
 
     def __init__(
         self,
+        *,
         channel: hmd.Channel,
         paramset_key: ParamsetKey,
         parameter: str,
@@ -51,7 +52,7 @@ class GenericDataPoint[ParameterT: GenericParameterType, InputParameterT: Generi
             parameter_data=parameter_data,
         )
 
-    @cached_property
+    @hm_property(cached=True)
     def usage(self) -> DataPointUsage:
         """Return the data_point usage."""
         if self._is_forced_sensor or self._is_un_ignored:
@@ -60,7 +61,7 @@ class GenericDataPoint[ParameterT: GenericParameterType, InputParameterT: Generi
             return self._get_data_point_usage()
         return DataPointUsage.DATA_POINT if force_enabled else DataPointUsage.NO_CREATE  # pylint: disable=using-constant-test
 
-    async def event(self, value: Any, received_at: datetime) -> None:
+    async def event(self, *, value: Any, received_at: datetime) -> None:
         """Handle event for which this data_point has subscribed."""
         self._device.client.last_value_send_cache.remove_last_value_send(
             dpk=self.dpk,
@@ -82,15 +83,16 @@ class GenericDataPoint[ParameterT: GenericParameterType, InputParameterT: Generi
             Parameter.UN_REACH,
             Parameter.STICKY_UN_REACH,
         ):
-            self._device.fire_device_updated_callback(self._unique_id)
-            self._central.fire_homematic_callback(
+            self._device.emit_device_updated_callback()
+            self._central.emit_homematic_callback(
                 event_type=EventType.DEVICE_AVAILABILITY,
-                event_data=self.get_event_data(new_value),
+                event_data=self.get_event_data(value=new_value),
             )
 
     @inspector
     async def send_value(
         self,
+        *,
         value: InputParameterT,
         collector: hme.CallParameterCollector | None = None,
         collector_order: int = 50,
@@ -107,10 +109,12 @@ class GenericDataPoint[ParameterT: GenericParameterType, InputParameterT: Generi
             return set()
 
         converted_value = self._convert_value(value=prepared_value)
+        # if collector is set, then add value to collector
         if collector:
-            collector.add_data_point(self, value=converted_value, collector_order=collector_order)
+            collector.add_data_point(data_point=self, value=converted_value, collector_order=collector_order)
             return set()
 
+        # if collector is not set, then send value directly
         if self._validate_state_change and not self.is_state_change(value=converted_value):
             return set()
 
@@ -121,7 +125,7 @@ class GenericDataPoint[ParameterT: GenericParameterType, InputParameterT: Generi
             value=converted_value,
         )
 
-    def _prepare_value_for_sending(self, value: InputParameterT, do_validate: bool = True) -> ParameterT:
+    def _prepare_value_for_sending(self, *, value: InputParameterT, do_validate: bool = True) -> ParameterT:
         """Prepare value, if required, before send."""
         return value  # type: ignore[return-value]
 
@@ -149,7 +153,7 @@ class GenericDataPoint[ParameterT: GenericParameterType, InputParameterT: Generi
             else DataPointUsage.DATA_POINT
         )
 
-    def is_state_change(self, value: ParameterT) -> bool:
+    def is_state_change(self, *, value: ParameterT) -> bool:
         """
         Check if the state/value changes.
 
