@@ -1,5 +1,5 @@
 # SPDX-License-Identifier: MIT
-# Copyright (c) 2021-2025 Daniel Perna, SukramJ
+# Copyright (c) 2021-2025
 """Support for data points used within aiohomematic."""
 
 from __future__ import annotations
@@ -32,7 +32,7 @@ from aiohomematic.const import (
     ParameterType,
 )
 from aiohomematic.model import device as hmd
-from aiohomematic.model.custom import definition as hmed
+from aiohomematic.model.custom.const import CDPD
 from aiohomematic.support import to_bool
 
 __all__ = [
@@ -74,7 +74,7 @@ class ChannelNameData:
         "sub_device_name",
     )
 
-    def __init__(self, device_name: str, channel_name: str) -> None:
+    def __init__(self, *, device_name: str, channel_name: str) -> None:
         """Init the DataPointNameData class."""
         self.device_name: Final = device_name
         self.channel_name: Final = self._get_channel_name(device_name=device_name, channel_name=channel_name)
@@ -87,7 +87,7 @@ class ChannelNameData:
         return ChannelNameData(device_name="", channel_name="")
 
     @staticmethod
-    def _get_channel_name(device_name: str, channel_name: str) -> str:
+    def _get_channel_name(*, device_name: str, channel_name: str) -> str:
         """Return the channel_name of the data_point only name."""
         if device_name and channel_name and channel_name.startswith(device_name):
             c_name = channel_name.replace(device_name, "").strip()
@@ -105,7 +105,7 @@ class DataPointNameData(ChannelNameData):
         "parameter_name",
     )
 
-    def __init__(self, device_name: str, channel_name: str, parameter_name: str | None = None) -> None:
+    def __init__(self, *, device_name: str, channel_name: str, parameter_name: str | None = None) -> None:
         """Init the DataPointNameData class."""
         super().__init__(device_name=device_name, channel_name=channel_name)
 
@@ -121,13 +121,13 @@ class DataPointNameData(ChannelNameData):
         return DataPointNameData(device_name="", channel_name="")
 
     @staticmethod
-    def _get_channel_parameter_name(channel_name: str, parameter_name: str | None) -> str:
+    def _get_channel_parameter_name(*, channel_name: str, parameter_name: str | None) -> str:
         """Return the channel parameter name of the data_point."""
         if channel_name and parameter_name:
             return f"{channel_name} {parameter_name}".strip()
         return channel_name.strip()
 
-    def _get_data_point_name(self, device_name: str, channel_name: str, parameter_name: str | None) -> str:
+    def _get_data_point_name(self, *, device_name: str, channel_name: str, parameter_name: str | None) -> str:
         """Return the name of the data_point only name."""
         channel_parameter_name = self._get_channel_parameter_name(
             channel_name=channel_name, parameter_name=parameter_name
@@ -145,7 +145,7 @@ class HubNameData:
         "name",
     )
 
-    def __init__(self, name: str, central_name: str | None = None, channel_name: str | None = None) -> None:
+    def __init__(self, *, name: str, central_name: str | None = None, channel_name: str | None = None) -> None:
         """Init the DataPointNameData class."""
         self.name: Final = name
         self.full_name = (
@@ -227,6 +227,7 @@ class DataPointPathData(PathData):
 
     def __init__(
         self,
+        *,
         interface: Interface | None,
         address: str,
         channel_no: int | None,
@@ -261,7 +262,7 @@ class ProgramPathData(PathData):
         "_state_path",
     )
 
-    def __init__(self, pid: str):
+    def __init__(self, *, pid: str):
         """Init the path data."""
         self._set_path: Final = f"{PROGRAM_SET_PATH_ROOT}/{pid}"
         self._state_path: Final = f"{PROGRAM_STATE_PATH_ROOT}/{pid}"
@@ -285,7 +286,7 @@ class SysvarPathData(PathData):
         "_state_path",
     )
 
-    def __init__(self, vid: str):
+    def __init__(self, *, vid: str):
         """Init the path data."""
         self._set_path: Final = f"{SYSVAR_SET_PATH_ROOT}/{vid}"
         self._state_path: Final = f"{SYSVAR_STATE_PATH_ROOT}/{vid}"
@@ -527,7 +528,7 @@ def _convert_value_noncached(value: Any, target_type: ParameterType, value_list:
             # relevant for ENUMs retyped to a BOOL
             return _get_binary_sensor_value(value=value, value_list=value_list)
         if isinstance(value, str):
-            return to_bool(value)
+            return to_bool(value=value)
         return bool(value)
     if target_type == ParameterType.FLOAT:
         return float(value)
@@ -564,7 +565,7 @@ def check_channel_is_the_only_primary_channel(
     device_has_multiple_channels: bool,
 ) -> bool:
     """Check if this channel is the only primary channel."""
-    primary_channel: int = device_def[hmed.CDPD.PRIMARY_CHANNEL]
+    primary_channel: int = device_def[CDPD.PRIMARY_CHANNEL]
     return bool(primary_channel == current_channel_no and device_has_multiple_channels is False)
 
 
