@@ -1,24 +1,21 @@
 # SPDX-License-Identifier: MIT
-# Copyright (c) 2021-2025 Daniel Perna, SukramJ
+# Copyright (c) 2021-2025
 """
 Decorators and helpers for declaring public attributes on data point classes.
 
 This module provides four decorator factories that behave like the built-in
 @property, but additionally annotate properties with a semantic category so they
 can be automatically collected to build payloads and log contexts:
-- cached_property: computed once per instance and cached until the value is
-  invalidated by a setter/deleter on the same descriptor.
 - config_property: configuration-related properties.
 - info_property: informational/metadata properties.
 - state_property: dynamic state properties.
+- hm_property: can be used to mark log_context or cached, where the other properties don't match
 
 All decorators accept an optional keyword-only argument log_context. If set to
 True, the property will be included in the LogContextMixin.log_context mapping.
 
 Notes on caching
-- cached_property always caches on first access and invalidates on set/delete.
-- The other decorators can be created with cached=True to enable the same
-  behavior when desired.
+- Marked with cached=True always store on first access and invalidates on set/delete.
 """
 
 from __future__ import annotations
@@ -68,6 +65,8 @@ class _GenericProperty[GETTER, SETTER](property):
 
     """
 
+    __kwonly_check__ = False
+
     fget: Callable[[Any], GETTER] | None
     fset: Callable[[Any, SETTER], None] | None
     fdel: Callable[[Any], None] | None
@@ -106,7 +105,7 @@ class _GenericProperty[GETTER, SETTER](property):
                 func_name = fdel.__name__
             else:
                 func_name = "prop"
-            self._cache_attr = f"_cached_{func_name}"  # Default name of the cache attribute
+            self._cache_attr = f"_cached_{func_name}"
 
     def getter(self, fget: Callable[[Any], GETTER], /) -> _GenericProperty:
         """Return generic getter."""
@@ -118,7 +117,7 @@ class _GenericProperty[GETTER, SETTER](property):
             kind=self.kind,
             cached=self._cached,
             log_context=self.log_context,
-        )  # pragma: no cover
+        )
 
     def setter(self, fset: Callable[[Any, SETTER], None], /) -> _GenericProperty:
         """Return generic setter."""
@@ -154,39 +153,64 @@ class _GenericProperty[GETTER, SETTER](property):
         if instance is None:
             # Accessed from class, return the descriptor itself
             return cast(GETTER, self)
-        if self.fget is None:
-            raise AttributeError("unreadable attribute")  # pragma: no cover
+
+        if (fget := self.fget) is None:
+            raise AttributeError("unreadable attribute")
 
         if not self._cached:
-            return self.fget(instance)
+            return fget(instance)
 
-        # If the cached value is not set yet, compute and store it
-        if not hasattr(instance, self._cache_attr):
-            value = self.fget(instance)
-            setattr(instance, self._cache_attr, value)
+        # Use direct __dict__ access when available for better performance
+        # Store cache_attr in local variable to avoid repeated attribute lookup
+        cache_attr = self._cache_attr
 
-        # Return the cached value
-        return cast(GETTER, getattr(instance, self._cache_attr))
+        try:
+            inst_dict = instance.__dict__
+            # Use 'in' check first to distinguish between missing and None
+            if cache_attr in inst_dict:
+                return cast(GETTER, inst_dict[cache_attr])
+
+            # Not cached yet, compute and store
+            value = fget(instance)
+            inst_dict[cache_attr] = value
+        except AttributeError:
+            # Object uses __slots__, fall back to getattr/setattr
+            try:
+                return cast(GETTER, getattr(instance, cache_attr))
+            except AttributeError:
+                value = fget(instance)
+                setattr(instance, cache_attr, value)
+        return value
 
     def __set__(self, instance: Any, value: Any, /) -> None:
         """Set the attribute value and invalidate cache if enabled."""
         # Delete the cached value so it can be recomputed on next access.
-        if self._cached and hasattr(instance, self._cache_attr):
-            delattr(instance, self._cache_attr)
+        if self._cached:
+            try:
+                instance.__dict__.pop(self._cache_attr, None)
+            except AttributeError:
+                # Object uses __slots__, fall back to delattr
+                if hasattr(instance, self._cache_attr):
+                    delattr(instance, self._cache_attr)
 
         if self.fset is None:
-            raise AttributeError("can't set attribute")  # pragma: no cover
+            raise AttributeError("can't set attribute")
         self.fset(instance, value)
 
     def __delete__(self, instance: Any, /) -> None:
         """Delete the attribute and invalidate cache if enabled."""
 
         # Delete the cached value so it can be recomputed on next access.
-        if self._cached and hasattr(instance, self._cache_attr):
-            delattr(instance, self._cache_attr)
+        if self._cached:
+            try:
+                instance.__dict__.pop(self._cache_attr, None)
+            except AttributeError:
+                # Object uses __slots__, fall back to delattr
+                if hasattr(instance, self._cache_attr):
+                    delattr(instance, self._cache_attr)
 
         if self.fdel is None:
-            raise AttributeError("can't delete attribute")  # pragma: no cover
+            raise AttributeError("can't delete attribute")
         self.fdel(instance)
 
 
@@ -235,45 +259,6 @@ def hm_property[PR](
     return _GenericProperty(func, kind=kind, cached=cached, log_context=log_context)
 
 
-# ----- cached_property -----
-
-
-@overload
-def cached_property[PR](func: Callable[[Any], PR], /) -> _GenericProperty[PR, Any]: ...
-
-
-@overload
-def cached_property(*, log_context: bool = ...) -> Callable[[Callable[[Any], R]], _GenericProperty[R, Any]]: ...
-
-
-def cached_property[PR](
-    func: Callable[[Any], PR] | None = None,
-    *,
-    log_context: bool = False,
-) -> _GenericProperty[PR, Any] | Callable[[Callable[[Any], PR]], _GenericProperty[PR, Any]]:
-    """
-    Decorate a method as a computed attribute with per-instance caching.
-
-    Supports both usages:
-    - @cached_property
-    - @cached_property(log_context=True)
-
-    Args:
-        func: The function being decorated when used as @cached_property without
-            parentheses. When used as a factory (i.e., @cached_property(...)), this
-            is None and the returned callable expects the function to decorate.
-        log_context: Include this property in structured log context if True.
-
-    """
-    if func is None:
-
-        def wrapper(f: Callable[[Any], PR]) -> _GenericProperty[PR, Any]:
-            return _GenericProperty(f, kind=Kind.SIMPLE, cached=True, log_context=log_context)
-
-        return wrapper
-    return _GenericProperty(func, kind=Kind.SIMPLE, cached=True, log_context=log_context)
-
-
 # ----- config_property -----
 
 
